==> clive-2.2.5.tbz: lib/perl5/site_perl/5.8.9/clive/Host/Myubo.pm <==
# -*- coding: ascii -*-
###########################################################################
# clive, command line video extraction utility.
#
# Copyright 2009 Toni Gundogdu.
#
# This file is part of clive.
#
# clive is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option)
# any later version.
#
# clive is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.
###########################################################################
package clive::Host::Myubo;

use warnings;
use strict;

sub new {
    return bless( {}, shift );
}

sub parsePage {
    my ( $self, $content, $props ) = @_;

    $$props->video_host("myubo");

    my %re = (
        id => qr|movieid=(.*?)"|i,
        title => qr|<div id="moviedetail"><h1>(.*?)</h1>|i,
        flv => qr|writeflashplayer\('(.*?)'|i,
    );

    my $tmp;
    if ( clive::Util::matchRegExps( \%re, \$tmp, $content ) == 0 ) {
        $$props->video_id($tmp->{id});
        $$props->page_title(undef, $tmp->{title});
        $$props->video_link($tmp->{flv});
        return(0);
    }
    return(1);
}

1;

==> clive-2.2.16.tbz: lib/perl5/site_perl/5.10.1/clive/Host/Myubo.pm <==
# -*- coding: ascii -*-
###########################################################################
# clive, command line video extraction utility.
#
# Copyright 2009 Toni Gundogdu.
#
# This file is part of clive.
#
# clive is free software: you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option)
# any later version.
#
# clive is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.
###########################################################################
package clive::Host::Myubo;

use warnings;
use strict;

sub new {
    return bless( {}, shift );
}

sub parsePage {
    my ( $self, $content, $props ) = @_;

    $$props->video_host("myubo");

    my %re = (
        id    => qr|movieid=(.*?)"|i,
        title => qr|<div id="moviedetail"><h1>(.*?)</h1>|i,
        url   => qr|writeflashplayer\('(.*?)'|i,
    );

    my $tmp;
    if ( clive::Util::matchRegExps( \%re, \$tmp, $content ) == 0 ) {
        $$props->video_id( $tmp->{id} );
        $$props->page_title( undef, $tmp->{title} );
        $$props->video_link( $tmp->{url} );
        return (0);
    }
    return (1);
}

1;
